# Changelog

## Unreleased (2025-11-05)

#### New Features

* Dynamic versions
* CI/CD to generate changelog
* Add pypi publishing
* Add sonarcloud configuration
#### Fixes

* Ensure CI builds correct version by handling conflicting git tags
* Subscribe to Document to avoid 'blinking' state
* update setuptools-scm configuration for proper version handling
* delete duplicate license
* change target branch to develop
* tests
#### Others

* fix isort
* Flake8
* black
* Add versioning convention
* linting
* fix license
* Add doc warning
* Update badge links
* update readme
* deploy docs on eveything branches/pushes (test)
